==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/handlers/PrometheusRuleHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.PrometheusRuleOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule;
import io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class PrometheusRuleHandler implements ResourceHandler<PrometheusRule, PrometheusRuleBuilder> {

  @Override
  public String getKind() {
    return PrometheusRule.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "monitoring.coreos.com/v1";
    }

  @Override
  public PrometheusRule create(OkHttpClient client, Config config, String namespace, PrometheusRule item) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public PrometheusRule replace(OkHttpClient client, Config config, String namespace, PrometheusRule item) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public PrometheusRule reload(OkHttpClient client, Config config, String namespace, PrometheusRule item) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public PrometheusRuleBuilder edit(PrometheusRule item) {
    return new PrometheusRuleBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, PrometheusRule item) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PrometheusRule item, Watcher<PrometheusRule> watcher) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PrometheusRule item, String resourceVersion, Watcher<PrometheusRule> watcher) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PrometheusRule item, ListOptions options, Watcher<PrometheusRule> watcher) {
  return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public PrometheusRule waitUntilReady(OkHttpClient client, Config config, String namespace, PrometheusRule item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public PrometheusRule waitUntilCondition(OkHttpClient client, Config config, String namespace, PrometheusRule item, Predicate<PrometheusRule> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.3.2-sources.jar: io/fabric8/openshift/client/handlers/PrometheusRuleHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.PrometheusRuleOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule;
import io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class PrometheusRuleHandler implements ResourceHandler<PrometheusRule, PrometheusRuleBuilder> {

  @Override
  public String getKind() {
    return PrometheusRule.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "monitoring.coreos.com/v1";
    }

  @Override
  public PrometheusRule create(OkHttpClient client, Config config, String namespace, PrometheusRule item, boolean dryRun) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public PrometheusRule replace(OkHttpClient client, Config config, String namespace, PrometheusRule item, boolean dryRun) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public PrometheusRule reload(OkHttpClient client, Config config, String namespace, PrometheusRule item) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public PrometheusRuleBuilder edit(PrometheusRule item) {
    return new PrometheusRuleBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, PrometheusRule item, boolean dryRun) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PrometheusRule item, Watcher<PrometheusRule> watcher) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PrometheusRule item, String resourceVersion, Watcher<PrometheusRule> watcher) {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PrometheusRule item, ListOptions options, Watcher<PrometheusRule> watcher) {
  return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public PrometheusRule waitUntilReady(OkHttpClient client, Config config, String namespace, PrometheusRule item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public PrometheusRule waitUntilCondition(OkHttpClient client, Config config, String namespace, PrometheusRule item, Predicate<PrometheusRule> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PrometheusRuleOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
